@@ -57,7 +57,7 @@ static CONST char *multiCommandTable[] = {
 };
 
 static CONST char *multiConfigTable[] = {
-    "-pipelining",
+    "-pipelining", "-maxconnects",
     (char *)NULL
 };
 
