@@ -42,7 +42,7 @@ extern "C" {
 #define TCL_STORAGE_CLASS DLLEXPORT
 #endif
 
-#define TclCurlVersion "7.16.2"
+#define TclCurlVersion "7.17.1"
 
 /*
  * This struct will contain the data of a transfer if the user wants
@@ -53,7 +53,8 @@ struct MemoryStruct {
     size_t size;
 };
 
-/* Struct that will be used for a linked list with all the
+/* 
+ * Struct that will be used for a linked list with all the
  * data for a post
  */
 struct formArrayStruct {
@@ -80,36 +81,18 @@ struct curlObjData {
     char                   *inFile;
     FILE                   *inHandle;
     int                     inFlag;
-    char                   *URL;
-    char                   *useragent;
-    char                   *referer;
     char                   *proxy;
     int                     transferText;
-    char                   *userpwd;
-    char                   *proxyuserpwd;
-    char                   *range;
     char                   *errorBuffer;
     char                   *errorBufferName;
     char                   *errorBufferKey;
-    char                   *postFields;
-    char                   *ftpport;
-    char                   *cookie;
-    char                   *cookiefile;
-    char                   *sslcert;
-    char                   *sslcertpasswd;
     char                   *headerFile;
     FILE                   *headerHandle;
     int                     headerFlag;
-    char                   *customrequest;
     char                   *stderrFile;
     FILE                   *stderrHandle;
     int                     stderrFlag;
-    char                   *interfaces;
-    char                   *krb4level;
-    char                   *cainfo;
-    char                   *capath;
     char                   *randomFile;
-    char                   *egdsocket;
     char                   *headerVar;
     char                   *bodyVarName;
     struct MemoryStruct     bodyVar;
@@ -118,25 +101,10 @@ struct curlObjData {
     int                     cancelTrans;
     char                   *writeProc;
     char                   *readProc;
-    char                   *cookiejar;
-    char                   *sslcipherlist;
-    char                   *sslcerttype;
-    char                   *sslkey;
-    char                   *sslkeytype;
-    char                   *sslkeypasswd;
-    char                   *sslengine;
-    char                   *sslenginedefault;
     char                   *debugProc;
-    char                   *encoding;
     struct curl_slist      *http200aliases;
     char                   *command;
-    char                   *netrcfile;
-    char                   *ftpAccount;
     int                     anyAuthFlag;
-    char                   *cookieList;
-    char                   *ftpAlternativeToUser;
-    char                   *sshpublickeyfile;
-    char                   *sshprivatekeyfile;
 };
 
 struct shcurlObjData {
@@ -205,7 +173,10 @@ static CONST char *optionTable[] = {
     "CURLOPT_SSH_AUTH_TYPES",                          "CURLOPT_SSH_PUBLIC_KEYFILE",
     "CURLOPT_SSH_PRIVATE_KEYFILE",                     "CURLOPT_TIMEOUT_MS",
     "CURLOPT_CONNECTTIMEOUT_MS",                       "CURLOPT_HTTP_CONTENT_DECODING",
-    "CURLOPT_HTTP_TRANSFER_DECODING",
+    "CURLOPT_HTTP_TRANSFER_DECODING",                  "CURLOPT_KRBLEVEL",
+    "CURLOPT_NEW_FILE_PERMS",                          "CURLOPT_NEW_DIRECTORY_PERMS",
+    "CURLOPT_KEYPASSWD",      "CURLOPT_APPEND",        "CURLOPT_DIRLISTONLY",
+    "CURLOPT_USE_SSL",        "CURLOPT_POST301",       "CURLOPT_SSH_HOST_PUBLIC_KEY_MD5",
     (char *) NULL
 };
 
@@ -256,7 +227,10 @@ static CONST char *configTable[] = {
     "-ftpalternativetouser",                     "-sslsessionidcache",
     "-sshauthtypes",      "-sshpublickeyfile",   "-sshprivatekeyfile",
     "-timeoutms",         "-connecttimeoutms",   "-contentdecoding",
-    "-transferdecoding",
+    "-transferdecoding",  "-krblevel",           "-newfileperms",
+    "-newdirectoryperms", "-keypasswd",          "-append",
+    "-dirlistonly",       "-usessl",             "-post301",
+    "-sshhostpublickeymd5",
     (char *) NULL
 };
 
@@ -385,7 +359,7 @@ int SetoptLong(Tcl_Interp *interp,CURL *curlHandle,CURLoption opt,int tableIndex
             Tcl_Obj *tclObj);
 int SetoptCurlOffT(Tcl_Interp *interp,CURL *curlHandle,CURLoption opt,int tableIndex,
             Tcl_Obj *tclObj);
-int SetoptChar(Tcl_Interp *interp,char **charPtr,CURL *curlHandle,CURLoption opt,
+int SetoptChar(Tcl_Interp *interp,CURL *curlHandle,CURLoption opt,
             int tableIndex,Tcl_Obj *tclObj);
 int SetoptSHandle(Tcl_Interp *interp,CURL *curlHandle,CURLoption opt,
         int tableIndex,Tcl_Obj *tclObj);
